@@ -4,7 +4,7 @@
  * --------
  * Author: Andreas Gohr (andi@splitbrain.org), Ben Keen (ben.keen@gmail.com)
  * Copyright: (c) 2004 Andreas Gohr, Ben Keen (http://www.benjaminkeen.org/), Nigel McNie (http://qbnz.com/highlighter/)
- * Release Version: 1.0.8.1
+ * Release Version: 1.0.8.11
  * Date Started: 2004/08/20
  *
  * Perl language file for GeSHi.
@@ -72,7 +72,7 @@ $language_data = array (
         //Heredoc
         4 => '/<<\s*?([\'"]?)([a-zA-Z0-9]+)\1;[^\n]*?\\n.*\\n\\2(?![a-zA-Z0-9])/siU',
         //Predefined variables
-        5 => '/\$(\^[a-zA-Z]?|[\$`\'&_\.,+\-~:\\\\\/"\|%=\?!@<>\(\)\[\]])|@_/',
+        5 => '/\$(\^[a-zA-Z]?|[\*\$`\'&_\.,+\-~:;\\\\\/"\|%=\?!@#<>\(\)\[\]])(?!\w)|@[_+\-]|%[!]|\$(?=\{)/',
         ),
     'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
     'QUOTEMARKS' => array('"','`'),
@@ -86,12 +86,12 @@ $language_data = array (
     'KEYWORDS' => array(
         1 => array(
             'case', 'do', 'else', 'elsif', 'for', 'if', 'then', 'until', 'while', 'foreach', 'my',
-            'or', 'and', 'unless', 'next', 'last', 'redo', 'not', 'our',
-            'reset', 'continue', 'cmp', 'ne'
+            'xor', 'or', 'and', 'unless', 'next', 'last', 'redo', 'not', 'our',
+            'reset', 'continue', 'cmp', 'ne', 'eq', 'lt', 'gt', 'le', 'ge',
             ),
         2 => array(
             'use', 'sub', 'new', '__END__', '__DATA__', '__DIE__', '__WARN__', 'BEGIN',
-            'STDIN', 'STDOUT', 'STDERR'
+            'STDIN', 'STDOUT', 'STDERR', 'ARGV', 'ARGVOUT'
             ),
         3 => array(
             'abs', 'accept', 'alarm', 'atan2', 'bind', 'binmode', 'bless',
@@ -130,9 +130,9 @@ $language_data = array (
         ),
     'SYMBOLS' => array(
         '<', '>', '=',
-        '!', '@', '~', '&', '|',
+        '!', '@', '~', '&', '|', '^',
         '+','-', '*', '/', '%',
-        ',', ';', '?', ':'
+        ',', ';', '?', '.', ':'
         ),
     'CASE_SENSITIVE' => array(
         GESHI_COMMENTS => false,
@@ -194,7 +194,7 @@ $language_data = array (
         ),
     'REGEXPS' => array(
         //Variable
-        0 => '[\\$%@]+[a-zA-Z_][a-zA-Z0-9_]*',
+        0 => '(?:\$[\$#]?|\\\\(?:[@%*]?|\\\\*\$|&amp;)|%[$]?|@[$]?|\*[$]?|&amp;[$]?)[a-zA-Z_][a-zA-Z0-9_]*',
         //File Descriptor
         4 => '&lt;[a-zA-Z_][a-zA-Z0-9_]*&gt;',
         ),
@@ -210,4 +210,4 @@ $language_data = array (
     )
 );
 
-?>
+?>
\ No newline at end of file
