@@ -4,7 +4,7 @@
  * --------
  * Author: Moises Deniz
  * Copyright: (c) 2007 Moises Deniz
- * Release Version: 1.0.8.4
+ * Release Version: 1.0.8.11
  * Date Started: 2007/03/21
  *
  * Ruby language file for GeSHi.
@@ -40,6 +40,10 @@ $language_data = array (
     'LANG_NAME' => 'Ruby',
     'COMMENT_SINGLE' => array(1 => "#"),
     'COMMENT_MULTI' => array("=begin" => "=end"),
+    'COMMENT_REGEXP' => array(
+        //Heredoc
+        4 => '/<<\s*?(\w+)\\n.*?\\n\\1(?![a-zA-Z0-9])/si',
+        ),
     'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
     'QUOTEMARKS' => array('"', '`','\''),
     'ESCAPE_CHAR' => '\\',
@@ -50,7 +54,7 @@ $language_data = array (
                 'ensure', 'for', 'if', 'in', 'module', 'while',
                 'next', 'not', 'or', 'redo', 'rescue', 'yield',
                 'retry', 'super', 'then', 'undef', 'unless',
-                'until', 'when', 'BEGIN', 'END', 'include'
+                'until', 'when', 'include'
             ),
         2 => array(
                 '__FILE__', '__LINE__', 'false', 'nil', 'self', 'true',
@@ -145,6 +149,7 @@ $language_data = array (
             ),
         'COMMENTS' => array(
             1 => 'color:#008000; font-style:italic;',
+            4 => 'color: #cc0000; font-style: italic;',
             'MULTI' => 'color:#000080; font-style:italic;'
             ),
         'ESCAPE_CHAR' => array(
@@ -223,4 +228,4 @@ $language_data = array (
     'TAB_WIDTH' => 2
 );
 
-?>
+?>
\ No newline at end of file
